"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRestApiHealthcheck = exports.createBrokerServerHealthcheck = void 0;
const dispatcher_1 = require("../../dispatcher");
const defaultBrokerServerUrl = 'https://broker.snyk.io';
const defaultApiBaseUrl = 'https://api.snyk.io';
const defaultTimeoutMs = 10000;
function createBrokerServerHealthcheck(config) {
    const url = config.BROKER_SERVER_URL || defaultBrokerServerUrl;
    return {
        checkId: 'broker-server-status',
        checkName: 'Broker Server Healthcheck',
        active: true,
        url: `${url}/healthcheck`,
        timeoutMs: defaultTimeoutMs,
    };
}
exports.createBrokerServerHealthcheck = createBrokerServerHealthcheck;
function createRestApiHealthcheck(config) {
    const url = config.API_BASE_URL || defaultApiBaseUrl;
    // check is enabled only for high availability mode
    const enabled = (0, dispatcher_1.highAvailabilityModeEnabled)(config);
    return {
        checkId: 'rest-api-status',
        checkName: 'REST API Healthcheck',
        active: enabled,
        url: `${url}/rest/openapi`,
        timeoutMs: defaultTimeoutMs,
    };
}
exports.createRestApiHealthcheck = createRestApiHealthcheck;
//# sourceMappingURL=http-checks.js.map